Test dataset
============

CTCF ChIP-seq
-----------------------------------------------------

.. list-table::
   :widths: 50,50,60

   * - Project 
     - `ENCODE <https://www.encodeproject.org/experiments/ENCSR000EGM/>`_
     - 
   * - Lab
     - Michael Snyder, Stanford
     -     
   * - TF
     - `CTCF (CCCTC-binding factor) <https://en.wikipedia.org/wiki/CTCF>`_
     -
   * - Bio sample
     - Homo sapiens K562
     -     
   * - Reference genome
     - `GRCh38 <https://www.ncbi.nlm.nih.gov/assembly/GCF_000001405.26/>`_
     - 
   * - narrowPeak (bed)
     - `ENCFF660GHM.bed.gz <https://www.encodeproject.org/files/ENCFF660GHM/@@download/ENCFF660GHM.bed.gz>`_
     - 2b9e2c2ba7afe8d64f5f3549ce16cf1a
   * - narrowPeak (bigBed)
     - `ENCFF400DFR.bigBed <https://www.encodeproject.org/files/ENCFF400DFR/@@download/ENCFF400DFR.bigBed>`_
     - 15bf51e2a37b8d93b44c8746b83583b4
   * - signal Pvalue (bigWig)
     - `ENCFF336UPT.bigWig <https://www.encodeproject.org/files/ENCFF336UPT/@@download/ENCFF336UPT.bigWig>`_
     - 883eb33a975e14130e142b98070b14c0

RAD21 ChIP-seq
--------------------------------------------------------

.. list-table::
   :widths: 50,50,60

   * - Project 
     - `ENCODE <https://www.encodeproject.org/experiments/ENCSR000EGM/>`_
     - 
   * - Lab
     - Michael Snyder, Stanford
     -     
   * - TF
     - `RAD21 <https://en.wikipedia.org/wiki/RAD21>`_
     -
   * - Bio sample
     - Homo sapiens K562
     -     
   * - Reference genome
     - `GRCh38 <https://www.ncbi.nlm.nih.gov/assembly/GCF_000001405.26/>`_
     - 
   * - narrowPeak (bed)
     - `ENCFF057JFH.bed.gz <https://www.encodeproject.org/files/ENCFF057JFH/@@download/ENCFF057JFH.bed.gz>`_
     - 0e638759eb09e8d0825d3d124b2c77d6
   * - narrowPeak (bigBed)
     - `ENCFF066JWO.bigBed <https://www.encodeproject.org/files/ENCFF066JWO/@@download/ENCFF066JWO.bigBed>`_
     - 92d3e303d3d880db5c9d604823e9831d
   * - signal Pvalue (bigWig)
     - `ENCFF130GMP.bigWig <https://www.encodeproject.org/files/ENCFF130GMP/@@download/ENCFF130GMP.bigWig>`_
     - c7e73bd2fba6a21a9d02da181e303578



Other files
------------

These files can be used as genomic "background". 


.. list-table:: Human (Homo sapiens). Reference genome: GRCh38/hg38
   :widths: 80,80,60
   :header-rows: 1
   
   * - Dataset
     - md5sum
     - Genomic Size
   * - `remap2022_CRM_hg38_v1_0.bed.gz <https://data.cyverse.org/dav-anon/iplant/home/liguow/cobind_files/remap2022_CisRegulatoryModules_hg38_v1_0.bed.gz>`_
     - 4717178cd730471f5ac897838c55847c
     - 1.48 gigabase
   * - `ENCODE_CCRE_hg38.bed.gz <https://data.cyverse.org/dav-anon/iplant/home/liguow/cobind_files/ENCODE_CandidateCisRegulatoryElements_hg38.bed.gz>`_
     - a572f25b1f7a51283591f4afd8f0c3b7
     - 253 megabase
   * - `GeneHancer_v4.4_hg38.bed.gz <https://data.cyverse.org/dav-anon/iplant/home/liguow/cobind_files/GeneHancer_v4.4_hg38.bed.gz>`_
     - e6fbecf8f637db49ce12d1390c6285b6
     - 342 megabase
   * - `CpG_island_hg38.bed.gz <https://data.cyverse.org/dav-anon/iplant/home/liguow/cobind_files/CpG_island_hg38.bed.gz>`_
     - 8c783529fb4a8f86b1d90d70afa6a1f7
     - 22 megabase


.. list-table:: Mouse (Mus musculus). Reference genome: GRCm39/mm39
   :widths: 80,80,60
   :header-rows: 1
   
   * - Dataset
     - md5sum  
     - Genomic Size
   * - `remap2022_CRM_mm39_v1_0.bed.gz <https://data.cyverse.org/dav-anon/iplant/home/liguow/cobind_files/remap2022_CisRegulatoryModules_mm39_v1_0.bed.gz>`_
     - 9c20058b6ab324f2292029566e59993a
     -


.. list-table:: Fly (Drosophila Melanogaster). Reference genome: dm6
   :widths: 80,80,60
   :header-rows: 1
   
   * - Dataset
     - md5sum 
     - Genomic Size
   * - `remap2022_CRM_dm6_v1_0.bed.gz <https://data.cyverse.org/dav-anon/iplant/home/liguow/cobind_files/remap2022_CisRegulatoryModules_dm6_v1_0.bed.gz>`_
     - 3633180a8cba0495147682cc9b288aca
     -
  

